function load_image

clear
clear global

global faces num numrow numcol vecsize meanface newfaces V D eigfaces errors
global avgerr

% get the directory from the user
dirstr = inputdlg('Please enter the directory containing the images');
[rows, cols] = size(dirstr);
if rows == 0 & cols == 0
    return;
end
files = dir(char(dirstr));
[rows, cols] = size(files);

% form the image matrice
h = waitbar(0, 'Please wait while loading the images ...');
num = 0;
for i = 1:rows
    if strcmp(files(i).name, '.') == 0 & strcmp(files(i).name, '..') == 0
        [r,c] = size(files(i).name);
        ext = files(i).name(c-3:c);
        if strcmp(files(i).name(c-3), '.') == 1 & (strcmp(ext, 'jpg') == 0 | strcmp(ext, 'bmp') == 0 | strcmp(ext, 'tif') == 0 | strcmp(ext, 'png') == 0 | strcmp(ext, 'hdf') == 0 | strcmp(ext, 'pcx') == 0 | strcmp(ext, 'xwd') == 0)

            face = imread([char(dirstr), '/', files(i).name]);
            if num == 0
                [numrow, numcol] = size(face);
                vecsize = numrow*numcol;
                meanface = zeros(vecsize, 1);
            end
	    faces(:,num+1) = reshape(transpose(face), vecsize, 1);
	    faces(:,num+1) = faces(:,num+1) - min(faces(:,num+1));
	    faces(:,num+1) = faces(:,num+1) * 255 / max(faces(:,num+1));
            meanface = meanface + double(faces(:,num+1));
            num = num + 1;
        end
    end
    waitbar(i/rows, h);
end
close(h);

% find the mean face image
% subtract the mean from the image matrice
h = waitbar(0, 'Subtracting the mean from all the images ...');
meanface = meanface / num;
for i = 1:num
    newfaces(:,i) = double(faces(:,i)) - meanface;
    waitbar(i/num, h);
end
close(h);

% form covariance matrice
h = waitbar(0.05, 'Finding the Eigenfaces ...');
[V,D] = eig(transpose(newfaces) * newfaces);
waitbar(0.1, h);
V = newfaces * V;
waitbar(0.15, h);
[Y, I] = sort(-1 * max(D));
waitbar(0.2, h);
for i = 1:num
    eigfaces(:,i) = V(:,I(i));
    eigfaces(:,i) = eigfaces(:,i) / norm(eigfaces(:,i));
    waitbar(0.2 + i * 0.8 / num, h);
end
close(h);

% Find errors
h = waitbar(0, 'Calculating the Errors ...');
errors = zeros(num - 1, num);
avgerr = zeros(num - 1,1);
for i = 1:num
    f = zeros(vecsize, 1);
    tf = transpose(newfaces(:,i));
    for j = 1:num-1
        img(j) = tf * eigfaces(:,j);
        f = f + (img(j) * eigfaces(:,j));
        errors(j,i) = sum(abs(newfaces(:,i) - f));
    end
    avgerr = avgerr + errors(:,i);
    waitbar(i/num, h);
end
avgerr = avgerr / num;
close(h);

set(findobj('Tag', 'load_image_pb'), 'Enable', 'off');
set(findobj('Tag', 'load_project_pb'), 'Enable', 'off');
set(findobj('Tag', 'show_mb'), 'Enable', 'on');
set(findobj('Tag', 'save_project_pb'), 'Enable', 'on');

liststr = cell(num, 1);
for i = 1:num
    liststr(i) = cellstr(['Image ', int2str(i)]);
end
set(findobj('Tag', 'show_list'), 'String', liststr);
set(findobj('Tag', 'show_list'), 'Value', 1);
set(findobj('Tag', 'show_mb'), 'Value', 1);
